import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
  long_description = fh.read()

setuptools.setup(
  name='pytimbr_sqla',
  version='1.0.7',
  author='timbr',
  author_email='contact@timbr.ai',
  description='Timbr Python SQLAlchemy connector',
  long_description=long_description,
  long_description_content_type="text/markdown",
  url='https://github.com/WPSemantix/timbr_python_SQLAlchemy',
  download_url = 'https://github.com/WPSemantix/timbr_python_SQLAlchemy/archive/refs/tags/v1.0.7.tar.gz',
  project_urls={
    "Bug Tracker": "https://github.com/WPSemantix/timbr_python_SQLAlchemy/issues"
  },
  license='MIT',
  packages=['pytimbr_sqla', 'TCLIService'],
  install_requires=[
    'future',
    'python-dateutil',
    'sasl>=0.2.1',
    'thrift>=0.13.0',
    'thrift_sasl>=0.1.0',
    'pure-sasl>=0.6.2',
    'sqlalchemy>=1.4.36,<2.0.0',
    'requests_kerberos>=0.12.0',
  ],
  extras_require={},
  package_data={},
  keywords = [
    'timbr',
    'timbr-python',
    'timbr-connector',
    'python-connector',
    'PyTimbr',
    'pytimbr',
    'py-timbr',
    'Py-Timbr',
    'pytimbr_sqla',
    'pytimbr_Sqla',
    'PyTimbr_Sqla',
    'pytimbr_SQla',
    'PyTimbr_SQla',
    'pytimbr_SQLa',
    'PyTimbr_SQLa',
    'pytimbr_SQlA',
    'PyTimbr_SQLA',
    'pytimbrsqlalchemy',
    'PyTimbrSqlalchemy',
    'PyTimbrSQlalchemy',
    'PyTimbrSQLalchemy',
    'PyTimbrSQLAlchemy',
    'Py-TimbrSQLAlchemy',
    'py-timbrsqlalchemy',
    'Py-Timbr-SQLAlchemy',
    'py-timbr-sqlalchemy',
  ],
  classifiers=[
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
  entry_points={
    'sqlalchemy.dialects': [
      'timbr = pytimbr_sqla.sqlalchemy_timbr:TimbrDialect',
      "timbr.http = pytimbr_sqla.sqlalchemy_timbr:TimbrHTTPDialect",
      "timbr.https = pytimbr_sqla.sqlalchemy_timbr:TimbrHTTPSDialect",
    ],
  }
)



from sqlalchemy.engine import create_engine
from TCLIService.ttypes import TOperationState

if __name__ == '__main__':
  # Declare the connection variables

  # General example
  hostname = '<TIMBR_IP/HOST>'
  port = '<TIMBR_PORT>'
  ontology = '<ONTOLOGY_NAME>'
  protocol = '<http/https>'
  username = '<TIMBR_USER/token>'
  password = '<TIMBR_PASSWORD/TOKEN_VALUE>'
  connect_args = {
    'configuration': {
      'set:hiveconf:hiveMetadata': 'true',
      'set:hiveconf:active_datasource': '<datasource_name>',
      'set:hiveconf:queryTimeout': '<TIMEOUT_IN_SECONDS>',
    },
  }

  # hostname - The IP / Hostname of the Timbr server (not necessarily the hostname of the Timbr platform).
  # port - The port to connect to in the Timbr server. Timbr's default port with enabled_ssl is 443 without SSL is 11000.
  # ontology = The name of the ontology (knowledge graph) to connect.
  # protocol - Connection protocol can be 'http' or 'https'.
  # username - Use 'token' as the username when connecting using a Timbr token, otherwise use the user name.
  # password - If using a token as a username then the pass is the token value, otherwise its the user's password.
  # connect_args - The connection special arguments for extra customization. The only argument you must have is the first one (set:hiveconf:hiveMetadata) the others are optional.

  # HTTP example
  hostname = 'mytimbrenv.com'
  port = '11000'
  ontology = 'my_ontology'
  protocol = 'http'
  username = 'timbr'
  password = 'StrongPassword'
  connect_args = {
    'configuration': {
      'set:hiveconf:hiveMetadata': 'true',
    },
  }

  # HTTPS example
  hostname = 'mytimbrenv.com'
  port = '443'
  ontology = 'my_ontology'
  protocol = 'https'
  username = 'timbr'
  password = 'StrongPassword'
  connect_args = {
    'configuration': {
      'set:hiveconf:hiveMetadata': 'true',
    },
  }

  # Create new sqlalchemy connection
  engine = create_engine(f"hive+{protocol}://{username}@{ontology}:{password}@{hostname}:{port}", connect_args = connect_args)

  # Connect to the created engine
  conn = engine.connect()
  dbapi_conn = engine.raw_connection()
  cursor = dbapi_conn.cursor()

  # Execute a query
  query = "SHOW CONCEPTS"
  cursor.execute(query)

  # Check the status of this execution
  status = cursor.poll().operationState
  while status in (TOperationState.INITIALIZED_STATE, TOperationState.RUNNING_STATE):
    status = cursor.poll().operationState

  # Get the results of the execution
  results_headers = [(desc[0], desc[1]) for desc in cursor.description]
  results = cursor.fetchall()

  # Display the results of the execution
  # Print the columns name
  for name, col_type in results_headers:
    print(f"{name} - {col_type}")
  # Print the results
  for result in results:
    print(result)